@@ -526,7 +526,7 @@ class Chemical:
         Excess enthalpy [J/mol].
     
     """
-    __slots__ = ('_ID', '_locked_state', '_other_names',
+    __slots__ = ('_ID', '_locked_state', 
                  '_phase_ref', '_eos', '_eos_1atm',
                  '_synonyms', *_names, *_groups, 
                  *_handles, *_data,
@@ -1355,7 +1355,7 @@ class Chemical:
         try:
             T = IQ_interpolation(lambda T: Psat(T) - P,
                                  Tmin, Tmax, Psat(Tmin) - P, Psat(Tmax) - P,
-                                 Tguess, 1e-3, 1e-1, checkroot=False)
+                                 Tguess, 1e-6, 1e-2, checkroot=False)
         except: return None
         return T
 
